yarp_repeat {#master}
-------------------------

## Important Changes

### Yarp companion

#### added command `yarp repeat`
* `yarp repeat` repeats in an output port all data received in an input port. The command is useful to control stream flows on a wifi/mobile connection.